@@ -27,7 +27,7 @@ use Opendata::GTFS::Type::Trip;
 
 class Opendata::GTFS::Feed using Moose {
 
-    our $VERSION = '0.0101'; # VERSION
+    our $VERSION = '0.0102'; # VERSION
 
     use Path::Tiny;
     use MooseX::AttributeDocumented;
@@ -210,7 +210,7 @@ Opendata::GTFS::Feed - Parse General Transit Feeds (GTFS)
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
 
 
 
@@ -456,6 +456,10 @@ C<count> -E<gt> C<count_$attribute>
 
 =end HTML
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
+
 =head1 HOMEPAGE
 
 L<https://metacpan.org/release/Opendata-GTFS-Feed>
