@@ -5,7 +5,7 @@ use warnings;
 # Insired by Throwable::X
 package Opendata::GTFS::Feed::Exception {
 
-    our $VERSION = '0.0101'; # VERSION:
+    our $VERSION = '0.0102'; # VERSION:
     use Moose::Role;
     use Throwable::X::Types;
 
@@ -56,7 +56,11 @@ Opendata::GTFS::Feed::Exception
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
 
 =head1 HOMEPAGE
 
