@@ -6,7 +6,7 @@ use warnings;
 
 class Opendata::GTFS::Feed::Exception::FeedContainsFaultyHeader with Opendata::GTFS::Feed::Exception using Moose {
 
-    our $VERSION = '0.0101'; # VERSION:
+    our $VERSION = '0.0102'; # VERSION:
     use Opendata::GTFS::Feed::Exception -all;
 
     has filename => (
@@ -41,7 +41,11 @@ Opendata::GTFS::Feed::Exception::FeedContainsFaultyHeader
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
 
 =head1 HOMEPAGE
 
