@@ -4,7 +4,7 @@ use warnings;
 
 package Opendata::GTFS::Standard {
 
-    our $VERSION = '0.0101'; # VERSION
+    our $VERSION = '0.0102'; # VERSION
 
     use base 'Moops';
     use List::AllUtils();
@@ -41,7 +41,11 @@ Opendata::GTFS::Standard
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
+
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
 
 =head1 HOMEPAGE
 
