@@ -7,7 +7,7 @@ use warnings;
 
 class Opendata::GTFS::Type::Agency using Moose {
 
-    our $VERSION = '0.0101'; # VERSION:
+    our $VERSION = '0.0102'; # VERSION:
 
     my @columns = qw/
         0 agency_id
@@ -44,7 +44,7 @@ Opendata::GTFS::Type::Agency - Agency
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
 
 
 
@@ -155,6 +155,10 @@ Version 0.0101, released 2015-02-19.
 
 =end HTML
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
+
 =head1 HOMEPAGE
 
 L<https://metacpan.org/release/Opendata-GTFS-Feed>
