@@ -7,7 +7,7 @@ use warnings;
 
 class Opendata::GTFS::Type::Stop using Moose {
 
-    our $VERSION = '0.0101'; # VERSION
+    our $VERSION = '0.0102'; # VERSION
 
     my @columns = qw/
         1 stop_id
@@ -49,7 +49,7 @@ Opendata::GTFS::Type::Stop - Stop
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
 
 
 
@@ -232,6 +232,10 @@ Version 0.0101, released 2015-02-19.
 
 =end HTML
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
+
 =head1 HOMEPAGE
 
 L<https://metacpan.org/release/Opendata-GTFS-Feed>
