@@ -14,7 +14,7 @@ extends  Types::Standard,
 
 {
 
-    our $VERSION = '0.0101'; # VERSION:
+    our $VERSION = '0.0102'; # VERSION:
 
     class_type Agency        => { class => 'Opendata::GTFS::Type::Agency' };
     class_type Calendar      => { class => 'Opendata::GTFS::Type::Calendar' };
@@ -44,7 +44,7 @@ Types::Opendata::GTFS - Types for Opendata::GTFS
 
 =head1 VERSION
 
-Version 0.0101, released 2015-02-19.
+Version 0.0102, released 2015-02-19.
 
 =head1 TYPES
 
@@ -100,6 +100,10 @@ L<Trip|Opendata::GTFS::Type::Trip>
 
 =back
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Opendata-GTFS-Feed>
+
 =head1 HOMEPAGE
 
 L<https://metacpan.org/release/Opendata-GTFS-Feed>
